@@ -51,9 +51,7 @@
     return(NULL)
   }
   class(treatment) <- 'vtreatment'
-  treatment$scales <- .getScales(pred,rescol,weights)
-  # trainScore <- .scoreCol(newVarName,pred,rescol,c(),NULL,weights)
-  # treatment$scoreFrame <- trainScore # not bothering to jackknife this one, as it is likely a weak signal
+  treatment$scales <- linScore(newVarName,pred,rescol,weights)
   treatment
 }
 
